==> db_hj3415-4.5.0-py2.py3-none-any.whl: db_hj3415/myredis/c101.py <==
from typing import List, Dict

from db_hj3415 import mymongo
from db_hj3415.myredis.corps import Corps
import pickle


class C101(Corps):
    REDIS_RECENT_SUFFIX = 'recent'
    def __init__(self, code: str):
        super().__init__(code, 'c101')
        self.mymongo_c101 = mymongo.C101(code)

    @property
    def code(self) -> str:
        return super().code

    @code.setter
    def code(self, code: str):
        # 부모의 세터 프로퍼티를 사용하는 코드
        super(C101, self.__class__).code.__set__(self, code) # type: ignore
        self.mymongo_c101.code = self.code

    def get_recent(self, refresh=False) -> dict:
        # code_page 앞 11글자가 코드와 c101 페이지임.
        redis_name = f"{self.code_page}_{self.REDIS_RECENT_SUFFIX}"

        def fetch_get_recent() -> dict:
           return self.mymongo_c101.get_recent(merge_intro=True)

        return self.fetch_and_cache_data(redis_name, refresh, fetch_get_recent)

    def get_trend(self, title: str, refresh=False) -> dict:
        """
        title에 해당하는 데이터베이스에 저장된 모든 값을 {날짜: 값} 형식의 딕셔너리로 반환한다.

        title should be in ['BPS', 'EPS', 'PBR', 'PER', '주가', '배당수익률', '베타52주', '거래량']

        리턴값 - 주가
        {'2023.04.05': '63900',
         '2023.04.06': '62300',
         '2023.04.07': '65000',
         '2023.04.10': '65700',
         '2023.04.11': '65900',
         '2023.04.12': '66000',
         '2023.04.13': '66100',
         '2023.04.14': '65100',
         '2023.04.17': '65300'}
        """
        # code_page 앞 11글자가 코드와 c101 페이지임.
        redis_name = self.code_page + '_trend'

        def fetch_get_trend(title_in) -> dict:
            return self.mymongo_c101.get_trend(title_in)

        return self.fetch_and_cache_data(redis_name, refresh, fetch_get_trend, title)

    @classmethod
    def bulk_get_recent(cls, codes: List[str], refresh=False) -> Dict[str, dict]:
        # --- (1) 파이프라인 GET ---
        pipe = cls.redis_client.pipeline()
        redis_keys = [f"{code}.c101_{cls.REDIS_RECENT_SUFFIX}" for code in codes]
        for redis_key in redis_keys:
            pipe.get(redis_key)
        results_from_redis = pipe.execute()  # [val1, val2, ...]

        final_results = {}
        missing_codes = []

        # refresh=True 이면 기존 데이터 무시하고 다시 계산해야 하므로 모두 missing 처리
        if refresh:
            missing_codes = codes[:]
        else:
            # refresh=False 이면, Redis 값이 None인 티커만 다시 계산
            for code, val in zip(codes, results_from_redis):
                if val is None:
                    missing_codes.append(code)
                else:
                    # Redis에 pickled 데이터가 있다면 언피클해서 담기
                    c101_recent_data = pickle.loads(val)
                    final_results[code] = c101_recent_data

        # --- (2) 필요한 티커만 직접 연산 ---
        newly_computed_data = {}
        for code in missing_codes:
            data = cls(code).get_recent(refresh=True)
            newly_computed_data[code] = data

        # --- (3) 파이프라인 SET ---
        if newly_computed_data:
            pipe = cls.redis_client.pipeline()
            for code, data in newly_computed_data.items():
                redis_key = f"{code}.c101_{cls.REDIS_RECENT_SUFFIX}"
                pickled_data = pickle.dumps(data)
                # SET + expire_time
                pipe.setex(redis_key, cls.DEFAULT_CACHE_EXPIRATION_SEC, pickled_data)
            pipe.execute()

        # 최종 결과 딕셔너리 (캐시에 있었던 것 + 새로 만든 것)
        final_results.update(newly_computed_data)
        return final_results

==> db_hj3415-4.5.3-py2.py3-none-any.whl: db_hj3415/myredis/c101.py <==
from typing import List, Dict

from db_hj3415 import mymongo
from db_hj3415.myredis.corps import Corps

from utils_hj3415 import setup_logger

mylogger = setup_logger(__name__, level='INFO')


class C101(Corps):
    REDIS_RECENT_SUFFIX = 'recent_data'
    def __init__(self, code: str):
        super().__init__(code, 'c101')
        self.mymongo_c101 = mymongo.C101(code)

    @property
    def code(self) -> str:
        return super().code

    @code.setter
    def code(self, code: str):
        # 부모의 세터 프로퍼티를 사용하는 코드
        super(C101, self.__class__).code.__set__(self, code) # type: ignore
        self.mymongo_c101.code = self.code

    def get_recent(self, refresh=False) -> dict:
        # code_page 앞 11글자가 코드와 c101 페이지임.
        redis_name = f"{self.code_page}_{self.REDIS_RECENT_SUFFIX}"

        def fetch_get_recent() -> dict:
           return self.mymongo_c101.get_recent(merge_intro=True)

        return self.fetch_and_cache_data(redis_name, refresh, fetch_get_recent)

    def get_trend(self, title: str, refresh=False) -> dict:
        """
        title에 해당하는 데이터베이스에 저장된 모든 값을 {날짜: 값} 형식의 딕셔너리로 반환한다.

        title should be in ['BPS', 'EPS', 'PBR', 'PER', '주가', '배당수익률', '베타52주', '거래량']

        리턴값 - 주가
        {'2023.04.05': '63900',
         '2023.04.06': '62300',
         '2023.04.07': '65000',
         '2023.04.10': '65700',
         '2023.04.11': '65900',
         '2023.04.12': '66000',
         '2023.04.13': '66100',
         '2023.04.14': '65100',
         '2023.04.17': '65300'}
        """
        # code_page 앞 11글자가 코드와 c101 페이지임.
        redis_name = self.code_page + '_trend'

        def fetch_get_trend(title_in) -> dict:
            return self.mymongo_c101.get_trend(title_in)

        return self.fetch_and_cache_data(redis_name, refresh, fetch_get_trend, title)

    @classmethod
    def bulk_get_recent(cls, codes: List[str], refresh=False) -> Dict[str, dict]:
        redis_names = [f"{code}.c101_{cls.REDIS_RECENT_SUFFIX}" for code in codes]
        return cls.bulk_get_or_compute(
            redis_names,
            lambda redis_name: cls(redis_name.split('.')[0]).get_recent(refresh=True),
            refresh=refresh)
